@@ -48,7 +48,7 @@ import sys
 
 import bigmler.dispatchers as bd
 from bigmler.parser import SUBCOMMANDS
-from bigmler.utils import SYSTEM_ENCODING
+from bigmler.utils import BIGML_SYS_ENCODING
 
 
 PYTHON3 = sys.version_info[0] == 3
@@ -72,7 +72,7 @@ def main(args=sys.argv[1:]):
 
     """
     if args:
-        if not args[0].lower() in SUBCOMMANDS:
+        if not args[0].lower().strip("\n") in SUBCOMMANDS:
             new_args = ["main"]
             new_args.extend(args)
         else:
@@ -80,9 +80,9 @@ def main(args=sys.argv[1:]):
         # checks if the old --delete syntax is used
         new_args = check_delete_option(new_args)
         if not PYTHON3:
-            new_args = [arg.decode(SYSTEM_ENCODING) for arg in new_args]
+            new_args = [arg.decode(BIGML_SYS_ENCODING) for arg in new_args]
 
-        subcommand = new_args[0]
+        subcommand = new_args[0].lower().strip("\n")
         if subcommand == "logistic-regression":
             bd.subcommand_dispatcher("logistic_regression", new_args)
         elif subcommand == "topic-model":
