@@ -25,7 +25,7 @@ from nose.tools import eq_
 from bigmler.tests.world import world, res_filename
 from subprocess import check_call, CalledProcessError
 from bigmler.checkpoint import file_number_of_lines
-from bigmler.utils import SYSTEM_ENCODING, PYTHON3, open_mode
+from bigmler.utils import BIGML_SYS_ENCODING, PYTHON3, open_mode
 from bigml.api import check_resource
 from bigmler.tests.common_steps import check_debug
 
@@ -64,7 +64,7 @@ def i_create_output(step, output=None, language=None, resource_type='source',
             command += u' --add-fields'
         command = check_debug(command)
         if not PYTHON3:
-            command.encode(SYSTEM_ENCODING)
+            command.encode(BIGML_SYS_ENCODING)
         retcode = check_call(command, shell=True)
         if retcode < 0:
             assert False
